@@ -47,7 +47,9 @@ param = {
     'device': 'gpu',
     'gpu_platform_id': 0,
     'gpu_device_id': 0,
-    'gpu_use_dp': True
+    'gpu_use_dp': True,
+
+    'force_col_wise': True
 }
 
 data = lgb.Dataset(X, y)
